@@ -233,7 +233,10 @@ def getIndicesInfoStoryPoint(presModel, worksheet, noSelectFilter=True, noFieldC
 
 def getDataFull(presModelMap, originSegments):
     dataSegments = {}
-    if ("dataDictionary" in presModelMap) and ("presModelHolder" in presModelMap["dataDictionary"]):
+    if (("dataDictionary" in presModelMap) and
+            ("presModelHolder" in presModelMap["dataDictionary"]) and
+            ("genDataDictionaryPresModel" in presModelMap["dataDictionary"]["presModelHolder"]) and
+            ("dataSegments" in presModelMap["dataDictionary"]["presModelHolder"]["genDataDictionaryPresModel"])):
         dataSegments = presModelMap["dataDictionary"]["presModelHolder"]["genDataDictionaryPresModel"]["dataSegments"]
 
     dataSegmentscp = copy.deepcopy(dataSegments)
@@ -273,13 +276,19 @@ def getData(dataFull, indicesInfo):
                 for value in index["valueIndices"]:
                     if value < len(t):
                         values.append(onDataValue(value, t, cstring))
-                frameData[f'{index["fieldCaption"]}-value'] = values
+                if f'{index["fieldCaption"]}-value' not in frameData:
+                    frameData[f'{index["fieldCaption"]}-value'] = values
+                else:
+                    frameData[f'{index["fieldCaption"]}-{index["fn"]}-value'] = values
             if len(index["aliasIndices"]) > 0:
                 values = []
                 for value in index["aliasIndices"]:
                     if value < len(t):
                         values.append(onDataValue(value, t, cstring))
-                frameData[f'{index["fieldCaption"]}-alias'] = values
+                if f'{index["fieldCaption"]}-alias' not in frameData:
+                    frameData[f'{index["fieldCaption"]}-alias'] = values
+                else:
+                    frameData[f'{index["fieldCaption"]}-{index["fn"]}-alias'] = values
         else:
             # if datatype is not found, try cstring
             t = cstring
@@ -288,18 +297,24 @@ def getData(dataFull, indicesInfo):
                 for value in index["valueIndices"]:
                     if value < len(t):
                         values.append(onDataValue(value, t, cstring))
-                frameData[f'{index["fieldCaption"]}-value'] = values
+                if f'{index["fieldCaption"]}-value' not in frameData:
+                    frameData[f'{index["fieldCaption"]}-value'] = values
+                else:
+                    frameData[f'{index["fieldCaption"]}-{index["fn"]}-value'] = values
             if len(index["aliasIndices"]) > 0:
                 values = []
                 for value in index["aliasIndices"]:
                     if value < len(t):
                         values.append(onDataValue(value, t, cstring))
-                frameData[f'{index["fieldCaption"]}-alias'] = values
+                if f'{index["fieldCaption"]}-alias' not in frameData:
+                    frameData[f'{index["fieldCaption"]}-alias'] = values
+                else:
+                    frameData[f'{index["fieldCaption"]}-{index["fn"]}-alias'] = values
     return frameData
 
 
 def getDataFullCmdResponse(presModel, originSegments, dataSegments={}):
-    if (not dataSegments) and ("dataDictionary" in presModel):
+    if (not dataSegments) and ("dataDictionary" in presModel) and ("dataSegments" in presModel["dataDictionary"]):
         dataSegments = presModel["dataDictionary"]["dataSegments"]
     dataSegmentscp = copy.deepcopy(dataSegments)
     originSegmentscp = copy.deepcopy(originSegments)
@@ -448,6 +463,7 @@ def getWorksheetCmdResponse(selectedZone, dataFull):
             "dataType": t.get("dataType"),
             "paneIndices": t["paneIndices"][0],
             "columnIndices": t["columnIndices"][0],
+            "fn": t.get("fn", "")
         }
         for t in columnsData["vizDataColumns"]
         if t.get("fieldCaption")
@@ -461,7 +477,8 @@ def getWorksheetDownloadCmdResponse(dataFull, underlyingDataTableColumns):
             "fieldCaption": t["fieldCaption"],
             "valueIndices": t["valueIndices"],
             "aliasIndices": t["aliasIndices"],
-            "dataType": t["dataType"]
+            "dataType": t["dataType"],
+            "fn": t.get("fn", "")
         }
         for t in underlyingDataTableColumns
         if t.get("fieldCaption")
